## Binary physics

Settings that control the binary physics in the simulation

## Timesteps

### `pts1`

Sets the timestep modifier for main sequence stars (`dtp *= pts1`)

Default: 0.001

Option details

- `positive values`: Timestep modifier
- `0.001`: Recommended value from Bannerjee+2019 for NS/BH progenitors
- `0.05`: Recommended value from Hurley+2000

### `pts2`

Sets the timestep modifier for Giant Branch (GB, CHeB, AGB, HeGB) stars (`dtp *= pts2`)

Default: 0.01

Option details

- `positive values`: Timestep modifier
- `0.01`: Recommended value from Hurley+2000

### `pts3`

Sets the timestep modifier for HG, HeMS stars (`dtp *= pts3`)

Default: 0.02

Option details

- `positive values`: Timestep modifier
- `0.02`: Recommended value from Hurley+2000

## Metallicity

### `zsun`

Sets the metallicity of the Sun which primarily affects stellar winds.

Default: 0.014

Option details

Note that the wind prescriptions for OB stars are calibrated to zsun = 0.019 as described in Vink+2001.

- `positive values`: Set the solar metallicity
- `0.014`: Following Asplund+2009

## Stellar Winds

### `windflag`

Selects the model for wind mass loss for each star

Default: 3

Option details

- `0`: Standard SSE/BSE (Hurley+2000)
- `1`: StarTrack (Belczynski+2008)
- `2`: Metallicity dependence for O/B stars and Wolf Rayet stars (Vink+2001, Vink+2005)
- `3`: Same as 2, but LBV-like mass loss for giants and non-degenerate stars beyond the Humphreys-Davidson limit

### `eddlimflag`

Adjusts the dependence of mass loss on metallicity for stars near the Eddington limit (see Grafener+2011, Giacobbo+2018).

Default: 0

Option details

- `0`: does not adjust metallicity dependence for stars near the Eddington limit
- `1`: adjusts metallicity dependence for stars near the Eddington limit as in Giacobbo+2018.

### `neta`

Reimers mass-loss coefficient (Equation 106 of SSE).

Default: 0.5

Option details

Note: this equation has a typo. There is an extra \(\eta\) out front; the correct rate is directly proportional to \(\eta\). See also Kurdritzki+1978, Section Vb for discussion.

- `positive values`: Set \(\eta\) value
- `0.5`: Sets \(\eta\) for Reimers mass loss to 0.5

### `bwind`

Binary enhanced mass loss parameter

Default: 0.0

Option details

This parameter is used to enhance mass loss in binaries. See Hurley+2000, Eq. 12 for more information.

- `positive values`: Sets the binary enhanced mass loss parameter, \(B_w\), from Hurley+2000, Eq. 12
- `0.0`: Default value (no effect on single stars)

### `hewind`

Helium star mass loss parameter

Default: 0.5

Option details

\( 10^{-13} {\rm \ \texttt{hewind} \ } L^{2/3}\) gives He star mass-loss. Equivalent to \(1 - \mu\) in the last equation on Hurley+2000, page 19.

- `positive values`: Sets the helium star mass loss parameter
- `0.5`: Default value

### `beta`

Wind velocity factor. \( v_{\rm wind}^2 \propto \beta\), see Hurley+2002, Eq. 9.

Default: 0.125

Option details

- `-1`: Follow StarTrack prescription for wind velocity factor, \(\beta_w\), from Belczynski+2008
- `positive values`: Sets the wind velocity factor, \(\beta_w\)
- `0.125`: Default value

### `xi`

Wind accretion efficiency factor, which gives the fraction of angular momentum lost via winds from the primary that transfers to the spin angular momentum of the companion.

Default: 0.5

Option details

Corresponds to \(\mu_w\) in Hurley+2002, Eq. 11

- `positive values`: Sets the wind accretion efficiency factor
- `0.5`: Default value

### `acc2`

Bondi-Hoyle wind accretion factor where the mean wind accretion rate onto the secondary is proportional to `acc2`. See Hurley+2002, Eq. 6.

Default: 1.5

Option details

This value is equivalent to \(\alpha_w\) in Hurley+2002, Eq. 6.

- `positive values`: Sets the Bondi-Hoyle wind accretion factor, \(\alpha_w\)
- `1.5`: Default value

## Common-envelope

Note: there are cases where a common envelope is forced regardless of the critical mass ratio for unstable mass transfer. In the following cases, a common envelope occurs regardless of the choices below:

- contact: the stellar radii go into contact (common for similar ZAMS systems)
- periapse contact: the periapse distance is smaller than either of the stellar radii (common for highly eccentric systems)
- core Roche overflow: either of the stellar radii overflow their component's Roche radius (in this case, mass transfer from the convective core is always dynamically unstable)

### `alpha1`

Common-envelope efficiency parameter which scales the efficiency of transferring orbital energy to the envelope. See Hurley+2002, Eq. 71.

Default: 1.0

Option details

This value is equivalent to \(\alpha\) in Hurley+2002, Eq. 71.

- `positive values`: Sets the common-envelope efficiency parameter, \(\alpha\)
- `1.0`: Default value

### `lambdaf`

Binding energy factor for common envelope evolution. The initial binding energy of the stellar envelope is proportional to \(1 / \lambda\). See Hurley+2002, Eq. 69.

Default: 0.0

Option details

- `positive values`: uses variable lambda prescription detailed in appendix of Claeys+2014 where lambdaf is the fraction of the ionization energy that can go into ejecting the envelope; to use this prescription without extra ionization energy, set lambdaf = 0
- `0.0`: As above, this is the default choice
- `-1.0`: Uses a fixed value (i.e. fixes \( \lambda \) to a value of -lambdaf)

### `ceflag`

Selects the model to set the initial orbital energy (choose whether to use total mass of the stars instead of the core masses)

Default: 1

Option details

- `0`: Use the core masses of the stars to set the initial orbital energy (as in Hurley+2002 Eq. 70)
- `1`: Use the total mass of the stars to set the initial orbital energy (as in de Kool 1990)

### `cekickflag`

Selects which mass and separation values to use when a supernova occurs during the CE and a kick needs to be applied.

Default: 2

Option details

- `0`: uses pre-CE mass and post-CE sep (BSE default)
- `1`: uses pre-CE mass and sep values
- `2`: uses post-CE mass and sep

### `cemergeflag`

Determines whether stars that begin a CE without a distinct core-envelope boundary automatically lead to merger in a CE. These systems include: kstars = [0,1,2,7,8,10,11,12].

Default: 1

Option details

Note that while the optimal choice is `cemergeflag=1` according to Belczynski+2008, `cemergeflag=0` allows for both options to be explored, since it is trivial to remove these systems from a population in post processing.

- `0`: allows the CE to proceed (optimistic CE)
- `1`: forces the stars to merge in the CE (pessimistic CE)

### `cehestarflag`

Uses fitting formulae from Tauris+2015 for evolving RLO systems with a helium star donor and compact object accretor. NOTE: this flag will override `cekickflag` if set

Default: 0

Option details

- `0`: Do not use the fitting formulae from Tauris+2015
- `1`: Use the fitting formulae from Tauris+2015 for final period only
- `2`: Use the fitting formulae from Tauris+2015 for both final mass and final period

### `qcflag`

Selects model to determine critical mass ratios for the onset of unstable mass transfer and/or a common envelope during RLO. NOTE: this is overridden by `qcrit_array` if any of its values are non-zero.

Default: 1

Option details

The table below shows the values for `qcflag` across the choices of this flag and the kstar type. The equations in the table correspond to:
- Eq.1: `qc = 0.362 + 1.0/(3.0*(1.0 - massc(j1)/mass(j1)))` (from Hjellming & Webbink 1983)
- Eq 2: `qc = (1.67d0-zpars(7)+2.d0*(massc(j1)/mass(j1))**5)/2.13d0` (from Claeys+ 2014)

- `0`: follows Section 2.6 of Hurley+2002 (Default BSE)
- `1`: same as 0 but with Hjellming & Webbink 1987 for GB/AGB stars
- `2`: follows Table 2 of Claeys+2014
- `3`: same as 2 but with Hjellming & Webbink 1987 for GB/AGB stars
- `4`: follows Section 5.1 of Belcyznski+2008 except for WD donors which follow BSE
- `5`: follows Section 2.3 of Neijssel+2020; mass transfer from stripped stars is always assumed to be dynamically stable

kstar | qc=0 | qc=1 | qc=2 | qc=3 | qc=4 | qc=5
--- | --- | --- | --- | --- | --- | ---
0 | 0.695 | 0.695 | 0.695 / 1.0 | 0.695 / 1.0 | 3.000 | 1.717
1 | 3 | 3 | 1.6 / 1.0 | 1.6 / 1.0 | 3.000 | 1.717
2 | 4 | 4 | 4.0 / 4.7619 | 4.0 / 4.7619 | 3.000 | 3.825
3 | Eq.2 | Eq.1 | Eq.2 / 1.15 | Eq.1 / 1.15 | 3.000 | Eq.1
4 | 3 | 3 | 3.0 / 3.0 | 3.0 / 3.0 | 3.000 | 3
5 | Eq.2 | Eq.1 | Eq.2 / 1.15 | Eq.1 / 1.15 | 3.000 | Eq.1
6 | Eq.2 | Eq.1 | Eq.2 / 1.15 | Eq.1 / 1.15 | 3.000 | Eq.1
7 | 3 | 3 | 3.0 / 3.0 | 3.0 / 3.0 | 1.700 | inf
8 | 0.784 | 0.784 | 4.0 / 4.7619 | 4.0 / 4.7619 | 3.500 | inf
9 | 0.784 | 0.784 | 0.784 / 1.15 | 0.784 / 1.15 | 3.500 | inf
10-14 | 0.628 | 0.628 | 3.0 / 0.625 | 3.0 / 0.625 | 0.628 | 0.628
Comparison of qcrit Values (Donor Mass/Accretor Mass) For Each Donor Kstar Type Across Flag Options

### `qcrit_array`

User-defined values for critical mass ratios for the onset of unstable mass transfer and a common envelope during RLOF.

Default: [0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0]

Option details

Array of dimensions (1,16) specifying user-input values for the critical mass ratios that govern the onset of unstable mass transfer and a common envelope. Each item is set individually for its associated kstar, and a value of 0.0 will apply the prescription specified qcflag for that kstar.
NOTE: Recall from the start of this section that there are cases where a common envelope is forced regardless of the critical mass ratio for unstable mass transfer.

- `[0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0]`: Default value, which applies the prescription specified by `qcrit` for each kstar type

## Natal kicks

### `kickflag`

Sets the particular natal kick prescription to use. Note that `sigmadiv`, `bhflag`, `bhsigmafrac`, `aic`, and `ussn`, which are described below, are only used when `abs(kickflag)=1`. Positive values use the Pfahl+2002 prescription for handling natal kicks.

Default: 1

Option details

- `1`: The standard COSMIC kick prescription, where kicks are drawn from a bimodal distribution with standard FeCCSN getting a kick drawn from a Maxwellian distribution with dispersion parameter `sigma` and ECSN/USSN are drawn according to `sigmadiv`. This setting has additional possible options for `bhflag`, `bhsigmafrac`, `aic` and `ussn`.
- `2`: Natal kicks are drawn according to `sigma` and scaled by the ejecta mass and remnant mass following Eq. 1 of Giacobbo & Mapelli 2020 with their default parameters (\(m_{\rm NS = 1.2 {\rm M_\odot}\), \(m_{\rm ej = 9 {\rm M_\odot}\))
- `3`: Natal kicks are drawn according to `sigma` and scaled by just the ejecta mass following Eq. 2 of Giacobbo & Mapelli 2020, which does not scale the kick by (\(m_{\rm NS\)
- `4`: Natal kicks are drawn according to Eq. 1 of Bray & Eldridge 2016, with their default parameters (\(\alpha=70 \, {\rm km/s}, \beta = 120 \, {\rm km/s)}
- `negative values`: Same as above settings but using the old Kiel & Hurley 2009 prescription for changing the orbital configuration of the binary, available for reproducibility purposes but not recommended for new work

### `sigma`

Sets the dispersion in the Maxwellian for the SN kick velocity in km/s

Default: 265.0

Option details

- `positive values`: Sets the dispersion in the Maxwellian for the SN kick velocity in km/s
- `265.0`: Default choice

### `bhflag`

Sets the model for how SN kicks are applied to BHs, where bhflag != 0 allows for velocity kick at BH formation

Default: 1

Option details

- `0`: No BH kick
- `1`: fallback-modulated kicks following Fryer+2012
- `2`: kicks decreased by ratio of BH mass to NS mass (1.44 Msun); conserves linear momentum
- `3`: BH natal kicks are not decreased compared to NS kicks and are drawn from the same Maxwellian distribution with dispersion = `sigma` set above

### `bhsigmafrac`

Sets a fractional modification which scales down sigma for BHs. This works in addition to whatever is chosen for bhflag, and is applied to sigma before the bhflag prescriptions are applied

Default: 1.0

Option details

- `values between [0, 1]`: reduces sigma by bhsigmafrac for BHs
- `1.0`: Default choice

### `sigmadiv`

Sets the modified ECSN kick strength

Default: -20.0

Option details

- `positive values`: divide sigma (defined above) by sigmadiv
- `negative values`: sets ECSN kicks to be drawn from a Maxwellian distribution with dispersion given by sigmadiv
- `-20.0`: Default choice

### `ecsn`

Allows for electron capture SNe and sets the maximum He-star mass (at core helium depletion) that will result in an ECSN

Default: 2.25

Option details

- `0`: turns off ECSN
- `positive values`: sets maximum He-star mass for ECSN; BSE (Hurley+2002) and StarTrack (Belczynski+2008) use ecsn = 2.25, while Podsiadlowksi+2004 argues that binarity can increase this to ecsn = 2.5
- `2.25`: Default choice

### `ecsn_low`

Sets the low end of the ECSN mass range

Default: 1.6

Option details

- `positive values`: sets maximum He-star mass for ECSN; BSE (Hurley+2002) uses ecsn_mlow = 1.6, StarTrack (Belczynski+2008) uses ecsn_mlow = 1.85, Podsiadlowksi+2004 argues that binarity can decrease this to ecsn_mlow = 1.4
- `1.6`: Default choice

### `aic`

Sets the model for accretion induced collapse SN natal kicks

Default: 1

Option details

Applies even if `ecsn = 0<.code>`

- `0`: AIC SN receive kicks drawn from Maxwellian with dispersion = sigma defined above
- `1`: sets AIC SN kick strength according to sigmadiv; NOTE that this will apply even if ecsn = 0.0

### `ussn`

Reduces kicks according to the sigmadiv selection for ultra-stripped supernovae, assumed to happen if a He-star undergoes a CE with a compact companion

Default: 1

Option details

- `0`: USSN receive kicks drawn from Maxwellian with dispersion = sigma defined above
- `1`: sets USSN kick strength according to sigmadiv

### `pisn`

Allows for (pulsational) pair instability supernovae and sets either the model to use or the maximum mass of the remnant.

Default: -2

Option details

- `0`: no pulsational pair instability SN
- `-1`: uses the formulae from Spera & Mapelli 2017
- `-2`: uses a polynomial fit to Table 1 in Marchant+2018
- `-3`: uses a polynomial fit to Table 5 in Woosley 2019
- `positive values`: turns on pulsational pair instability and pair instability SNe, and sets the maximum mass of the allowed remnant (i.e., the bottom of the pair instability mass gap). He core masses between pisn and 65 Msun are assumed to go through pulsational pair instability and limit the He core mass to pisn, while He core masses from 65-135 Msun are assumed have a pair instability SN and leave no remnant.

### `polar_kick_angle`

Sets the opening angle of the SN kick relative to the pole of the exploding star

Default: 90.0

Option details

- `values between [0, 90]`: Sets the opening angle of the SN kick relative to the pole of the exploding star
- `0.0`: Strictly polar kicks
- `90.0`: Fully isotropic kicks (default choice)

### `natal_kick_array`

Array of dimensions (2,5) which takes user input values for the SN natal kick, where the first row corresponds to the first star and the second row corresponds to the second star and columns are: [vk, phi, theta, mean_anomaly, rand_seed].

Default: [[-100.0, -100.0, -100.0, -100.0, 0.0], [-100.0, -100.0, -100.0, -100.0, 0.0]]

Option details

NOTE: any numbers outside the ranges below will be sampled in the standard ways detailed above.

- `vk`: SN kick velocity in km/s, valid on the range [0, inf]
- `phi`: SN kick co-lateral polar angle in degrees, valid on the range [-90, 90]
- `theta`: SN kick azimuthal angle in degrees, valid on the range [0, 360]
- `mean_anomaly`: SN kick mean anomaly in degrees, valid on the range [0, 360]
- `rand_seed`: supplied if restarting evolution after a supernova has already occurred
- `[[-100.0, -100.0, -100.0, -100.0, 0.0], [-100.0, -100.0, -100.0, -100.0, 0.0]]`: Default choice, which applies the standard natal kick prescription

## Remnant mass

### `remnantflag`

Determines the remnant mass prescription used for NSs and BHs.

Default: 4

Option details

- `0`: follows Section 6 of Hurley+2000 (default BSE)
- `1`: follows Belczynski+2002
- `2`: follows Belczynski+2008
- `3`: follows the rapid prescription from Fryer+2012, with updated proto-core mass from Giacobbo & Mapelli 2020. This leads to a mass gap between neutron stars and black holes.
- `4`: follows the delayed prescription from Fryer+2012. This fills the mass gap between neutron stars and black holes.

### `mxns`

Sets the boundary between the maximum NS mass and the minimum BH mass

Default: 3.0

Option details

- `positive values`: Sets the boundary between the maximum NS mass and the minimum BH mass
- `3.0`: Default choice

### `rembar_massloss`

Determines the prescriptions for mass conversion due to neutrino emission during the collapse of the proto-compact object

Default: 0.5

Option details

- `positive values`: sets the maximum amount of mass loss, which should be about 10% of the maximum mass of an iron core (\({\sim 5 \mathrm{M}_\odot}\) Fryer, private communication)
- `values in [-1, 0)`: assumes that proto-compact objects lose a constant fraction of their baryonic mass when collapsing to a black hole, such that \(M_{\rm rem} = (1 + \texttt{rembar\_massloss}) M_{\rm rem}\) (e.g., rembar_massloss = -0.1 gives the black hole a gravitational mass that is 90% of the proto-compact object's baryonic mass)
- `0.5`: Default choice

### `wd_mass_lim`

Determines if the maximum white dwarf mass is limited to the chandraekhar mass during merger induced collapse

Default: 1

Option details

- `0`: Do not apply the limit
- `1`: Apply the limit

## Remnant spin

### `bhspinflag`

Uses different prescriptions for BH spin after formation

Default: 0

Option details

- `0`: sets all BH spins to bhspinmag
- `1`: draws a random BH spin between 0 and bhspinmag for every BH
- `2`: core-mass dependent BH spin (based on Belczynski+2017 v1)

### `bhspinmag`

Sets either the spin of all BHs or the upper limit of the uniform distribution for BH spins (see bhspinflag)

Default: 0.0

Option details

- `positive values`: Sets either the spin of all BHs or the upper limit of the uniform distribution for BH spins (see bhspinflag)
- `0.0`: Default choice

## GR Orbital Decay

### `grflag`

Turns on or off orbital decay due to gravitational wave emission

Default: 1

Option details

- `0`: No orbital decay due to gravitational wave emission
- `1`: Orbital decay due to gravitational wave emission is turned on

## Mass transfer

### `eddfac`

Eddington limit factor for mass transfer.

Default: 1

Option details

- `1`: mass transfer rate is limited by the Eddington rate following Equation 67 in Hurley+2002
- `values > 1`: permit super-Eddington accretion up to value `eddfac`
- `values in [0, 1]`: restrict accretion limit to fraction of Eddington (sub-Eddington accretion)

### `gamma`

Angular momentum prescriptions for mass lost during Roche-lobe overflow at super-Eddington mass transfer rates

Default: -2

Option details

- `-1`: assumes the lost material carries away the specific angular momentum of the primary
- `-2`: assumes material is lost from the system as if it is a wind from the secondary
- `-3`: assumes mass is lost through the outer Lagrangian point, forming a circumbinary disk. See Zapartas+17 Eq. 9 and Artymowicz & Lubow (1994).
- `positive values`: assumes that the lost material takes away a fraction `gamma` of the orbital angular momentum

### `don_lim`

Determines the rate of mass loss through Roche-lobe overflow mass transfer from the donor star

Default: -1

Option details

- `-1`: donor mass loss rate is calculated following Hurley+2002
- `-2`: donor mass loss rate is calculated following Claeys+2014

### `acc_lim`

Limits the amount of mass accreted during Roche-lobe overflow

Default: -1

Option details

- `-1`: limited to 10x the thermal rate of the accretor for MS/HG/CHeB and unlimited for GB/EAGB/AGB stars
- `-2`: limited to 1x the thermal rate of the accretor for MS/HG/CHeB and unlimited for GB/EAGB/AGB stars
- `-3`: limited to 10x the thermal rate of the accretor for all stars
- `-4`: limited to 1x the thermal rate of the accretor for all stars
- `>= 0`: sets overall fraction of donor material that is accreted, with the rest being lost from the system (`acc_lim = 0.5` assumes 50% accretion efficiency as in Belczynski+2008)

## Tides

### `tflag`

Activates tidal circularization following Hurley+2002

Default: 1

Option details

- `0`: No tidal circularization
- `1`: Tidal circularization is turned on

### `ST_tide`

Activates StarTrack setup for tides following Belczynski+2008

Default: 1

Option details

- `0`: Follows BSE (Hurley+2002)
- `1`: Follow StarTrack (Belczynski+2008). Note StarTrack method does not use a better integration scheme (yet) but simply ; follows similar set up to startrack (including initial vrot, using roche-lobe check ; at periastron, and circularisation and synchronisation at start of MT).

### `fprimc_array`

Controls the scaling factor for convective tides. Each value in the array is set individually for its associated kstar. The relevant equation is Hurley+2002 Eq. 21.

Default: [2.0/21.0,2.0/21.0,2.0/21.0,2.0/21.0,2.0/21.0,2.0/21.0,2.0/21.0,2.0/21.0,2.0/21.0,2.0/21.0,2.0/21.0,2.0/21.0,2.0/21.0,2.0/21.0,2.0/21.0,2.0/21.0]

Option details

- `positive values`: sets scaling factor of Equation 21 referenced above
- `[2.0/21.0,2.0/21.0,2.0/21.0,2.0/21.0,2.0/21.0,2.0/21.0,2.0/21.0,2.0/21.0,2.0/21.0,2.0/21.0,2.0/21.0,2.0/21.0,2.0/21.0,2.0/21.0,2.0/21.0,2.0/21.0]`: Default choice, which applies the standard scaling factor

## White dwarfs

### `ifflag`

Activates the initial-final white dwarf mass relation from Han+1995 Equations 3, 4, and 5.

Default: 1

Option details

- `0`: No modifications to BSE
- `1`: Initial-final white dwarf mass relation is turned on

### `wdflag`

Activates an alternate cooling law found in the description immediately following Equation 1 in Hurley & Shara 2003. Equation 1 gives the BSE default Mestel cooling law.

Default: 1

Option details

- `0`: No modifications to BSE
- `1`: Alternate cooling law is turned on

### `epsnov`

Fraction of accreted matter retained in a nova eruption. This is relevant for accretion onto degenerate objects; see Section 2.6.6.2 in Hurley+2002.

Default: 0.001

Option details

- `positive values`: Retains epsnov fraction of accreted matter
- `0.001`: Default choice

## Pulsars

### `bdecayfac`

Activates different models for accretion induced field decay; see Kiel+2008.

Default: 1

Option details

- `0`: uses an exponential decay
- `1`: uses an inverse decay

### `bconst`

Sets the magnetic field decay timescale for pulsars following Section 3 of Kiel+2008.

Default: 3000

Option details

- `positive values`: sets \(k\) in Myr from Equation 8 to `bconst`
- `3000`: Default choice

### `ck`

Sets the magnetic field decay timescale for pulsars following Section 3 of Kiel+2008.

Default: 1000

Option details

- `positive values`: sets \(\tau_b\) in Myr from Equation 2 to `ck`
- `1000`: Default choice

## Mixing variables

### `rejuv_fac`

Sets the mixing factor in main sequence star collisions. This is hard coded to 0.1 in the original BSE release and in Equation 80 of Hurley+2002 but can lead to extended main sequence lifetimes in some cases.

Default: 1.0

Option details

- `positive values`: sets the mixing factor in main sequence star collisions
- `1.0`: Default choice

### `rejuvflag`

Sets whether to use the orginal prescription for mixing of main-sequence stars (based on equation 80 of Hurley+2002) or whether to use the ratio of the pre-merger He core mass at the base of the giant branch to the merger product's He core mass at the base of the giant branch

Default: 0

Option details

- `0`: No modifications to BSE
- `1`: modified mixing times

### `bhms_coll_flag`

If set to 1, then the star is not destroyed in a BH+star collision if \(M_{\rm star} > M_{\rm BH}\)

Default: 0

Option details

- `0`: Star is destroyed in a BH+star collision even if \(M_{\rm star} > M_{\rm BH}\)
- `1`: Star is not destroyed in a BH+star collision if \(M_{\rm star} > M_{\rm BH}\)

## Magnetic Braking

### `htpmb`

Activates different models for magnetic braking

Default: 1

Option details

- `-1`: No magnetic braking
- `0`: No modifications to BSE
- `1`: follows Ivanona and Taam 2003

## Miscellaneous

### `ST_cr`

Activates different convective vs radiative boundaries

Default: 1

Option details

- `0`: Follows BSE (Hurley+2002)
- `1`: Follow StarTrack (Belczynski+2008)

### `rtmsflag`

Flag for calculating the radius at the end of the main sequence.

Default: 0

Option details

- `0`: Use the original SSE calculation except if M>200Msun and Z<0.0008 (~0.04 Zsun). For the exception, an extrapolation is used. This ad hoc extrapolation works well for stars with M < 4000 Msun for Z >= 0.01 Zsun. For lower metallicities, you may still run into issues of negative radii for very massive stars - use at your own risk.
- `1`: Calculate using BoOST simulation data. BoOST metallicities = [1.1e-4, 2.1e-4, 1e-3, 2e-3] corresponding to [dwarfD, IZw18, dwarfA, SMC] models (Szecsi et al. (2022))
- `2`: Calculating using BPASS simulation data. BPASS metallicities = [1e-4, *2e-4*, 1e-3, 2e-3]. NOTE : For BPASS, we used a power law to fit the rtms v/s mzams values for each metallicity. We have coded the best fit power-laws for the above BPASS metallicities here. Since, Z = 2e-4 model is not available in the BPASS tracks, we assume the same rtms v/s mzams power law as Z=1e-4 for Z=2e-4.